@@ -19,11 +19,14 @@
  *************************************************************************/
 
 #include "oxygenstyleplugin.h"
-#include "oxygenstyleplugin.moc"
 #include "oxygenstyle.h"
 
 #include <QApplication>
 
+#if QT_VERSION < 0x050000
+Q_EXPORT_PLUGIN2( oxygen-qt, Oxygen::StylePlugin )
+#endif
+
 namespace Oxygen
 {
 
